@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: texmath
 version: 0.8.4.1
-id: texmath-0.8.4.1-615fcd9f0f47950878c0b6627370a99b
-key: texma_Ejgl9yfatvF9TOYq8yuU1H
+id: texmath-0.8.4.1-223a47f7c3c1b47e98791079ee795ead
+key: texma_CeXgwPXXJKtEeqwQ0dhWl5
 license: GPL
 maintainer: jgm@berkeley.edu
 stability: Experimental
@@ -59,15 +59,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.4.1
-hs-libraries: HStexmath-0.8.4.1-Ejgl9yfatvF9TOYq8yuU1H
+hs-libraries: HStexmath-0.8.4.1-CeXgwPXXJKtEeqwQ0dhWl5
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-types-1.16.0.1-2ad43357aa63c8920d27bb68c5d729c7
-    parsec-3.1.9-76531bee8e01e972cbf1b63ff50c8cf1
+    pandoc-types-1.16.0.1-34128572b9929354379ebf9e0bcb880e
+    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    xml-1.3.14-037fe275fa3de94cb01ef56b31420e0a
+    xml-1.3.14-47d6d03c8a900e03cf8951206101564b
 haddock-interfaces: /usr/share/doc/haskell-texmath/html/texmath.haddock
 haddock-html: /usr/share/doc/haskell-texmath/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
